<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// A
	'affichage_documents_en_cases' => 'Montri kvadrate',
	'affichage_documents_en_grand' => 'Montri grande',
	'affichage_documents_en_liste_compacte' => 'Montri kompaktliste',
	'aucun_audio' => 'Neniu sontrako',
	'aucun_document' => 'Neniu dokumento',
	'aucun_file' => 'Neniu dokumento',
	'aucun_image' => 'Neniu bildo',
	'aucun_video' => 'Neniu filmo',
	'aucune_utilisation' => 'Tiu dokumento estas neuzata',
	'aucune_vignette' => 'Neniu vinjeto',

	// B
	'bouton_ajouter_document' => 'Aldoni dokumenton',
	'bouton_ajouter_image' => 'Aldoni bildon',
	'bouton_ajouter_image_document' => 'Aldoni bildon aŭ dokumenton',
	'bouton_attacher_document' => 'Ligi',
	'bouton_copier_local' => 'Kopii en la retejo',
	'bouton_download_depuis' => 'ekde :',
	'bouton_download_local' => 'mia komputilo',
	'bouton_download_par_ftp' => 'la servilo',
	'bouton_download_par_mediatheque' => 'la aŭdvidea biblioteko',
	'bouton_download_sur_le_web' => 'Interreto',
	'bouton_enlever_document' => 'Malligi',
	'bouton_enlever_supprimer_document' => 'Forigi',
	'bouton_enlever_supprimer_document_confirmation' => 'Ĉu vi certas, ke vi volas forigi la dokumenton ?',
	'bouton_modifier_document' => 'Modifi',
	'bouton_parcourir' => 'Elekti...',
	'bouton_refresh_document' => 'Aktualigi la dokumenton',
	'bouton_remplacer_document' => 'Anstataŭigi la dokumenton',
	'bouton_remplacer_image' => 'Anstataŭigi tiun bildon',
	'bouton_remplacer_image_document' => 'Anstataŭigi per bildo aŭ dokumento',
	'bouton_supprimer' => 'Forigi',
	'bouton_supprimer_tous_orphelins' => 'Forigi ĉiujn orfaĵojn', # MODIF
	'bouton_supprimer_tous_orphelins_confirmation' => 'Ĉu vi certas, ke vi volas forigi @nb@ orfaĵojn ?', # MODIF
	'bouton_upload' => 'Alŝuti',

	// D
	'des_audios' => '@nb@ sontrakoj',
	'des_documents' => '@nb@ dokumentoj',
	'des_files' => '@nb@ dokumentoj',
	'des_images' => '@nb@ bildoj',
	'des_utilisations' => '@nb@ uzoj',
	'des_videos' => '@nb@ filmoj',
	'descriptif' => 'Priskribo', # MODIF
	'details_document' => 'Detaloj',
	'details_document_afficher_masquer' => 'Montri / kaŝi la detalojn de la dokumento',
	'document_attache_succes' => 'La dokumento estis aldonita',
	'document_copie_locale_succes' => 'La dosiero bone estis kopiita en la retejon',
	'document_installe_succes' => 'La dosiero sukcese estis alŝutita',
	'document_vu' => 'Enmetita en la tekston',
	'documents' => 'Aŭdvidea biblioteko',
	'documents_brises' => 'Ne plus funkciantaj',
	'documents_distants' => 'Foraj',
	'documents_locaux' => 'Lokaj',
	'documents_non_publies' => 'Ne publikigitaj',
	'documents_orphelins' => 'Ne uzitaj',
	'documents_publies' => 'Publikigitaj',
	'documents_tous' => 'Ĉio',
	'double_clic_inserer_doc' => 'Dufoje musklaku por enigi tiun rapidligilon en la tekston',

	// E
	'entree_dimensions' => 'Dimensioj :',
	'entree_titre_document' => 'Titolo de la dokumento :',
	'entree_titre_image' => 'Bildtitolo :',
	'erreur_aucun_document' => 'Tiu dokumento ne ekzistas en la aŭdvidea bibloteko',
	'erreur_aucun_fichier' => 'Neniu dosiero estis trovita',
	'erreur_autorisation' => 'Permeso fiaskis.',
	'erreur_chemin_distant' => 'La fora dosiero @nom@ ne estis trovita',
	'erreur_chemin_ftp' => 'La indikita dosiero ne troveblas ĉe la servilo',
	'erreur_copie_fichier' => 'Ne eblas kopii la dosieron @nom@',
	'erreur_deplacement_impossible' => 'Ne eblas movi.',
	'erreur_dossier_tmp_manquant' => 'Provizora dosierujo mankas por elŝuti la dosierojn',
	'erreur_ecriture_fichier' => 'Eraro dum diskoskribo de la dosiero',
	'erreur_format_fichier_image' => 'La dosierformo de @nom@ ne taŭgas por bildo',
	'erreur_indiquez_un_fichier' => 'Indiku dosiero !',
	'erreur_insertion_document_base' => 'Ne eblas konservi la dokumenton @fichier@ en la datumbazon',
	'erreur_objet_absent' => 'Ricevitaj informoj nekompletaj.',
	'erreur_suppression_vignette' => 'Eraro okaze de la forigo de la vinjeto',
	'erreur_upload_type_interdit' => 'La alŝuto de dosieroj el formo @nom@ ne estas permesita',
	'erreur_upload_vignette' => 'Eraro okaze de la ŝargo de la vinjeto @nom@',
	'erreurs' => '@nb@ eraroj',
	'erreurs_voir' => 'Vidi la @nb@ erarojn',

	// F
	'fichier_distant' => 'Fora dosiero',
	'fichier_manquant' => 'Mankanta dosiero',
	'fichier_modifie' => 'La dosiero estis modifita. Alklaku al „Konservi“',
	'format_date_incorrect' => 'La dato aŭ la horo ne validas',

	// I
	'icone_creer_document' => 'Aldoni dokumenton',
	'id' => 'Identigilo',
	'image_tourner_180' => 'Rotacio 180°',
	'image_tourner_droite' => '90° rotacio dekstren',
	'image_tourner_gauche' => '90° rotacio maldekstren',
	'info_dimensions_image' => 'Dimensioj',
	'info_doc_max_poids' => 'La dokumentoj nepre dimensiu malpli ol @maxi@ (tiu dosiero dimensias @actuel@).',
	'info_document' => 'Dokumento ',
	'info_document_indisponible' => 'Tiu ĉi dokumento ne disponeblas',
	'info_documents' => 'Dokumentoj',
	'info_duree' => 'Daŭro',
	'info_gauche_numero_document' => 'DOKUMENTO NUMERO',
	'info_hauteur' => 'Alto',
	'info_heure' => 'Horo',
	'info_illustrations' => 'Ilustraĵoj',
	'info_image_max_poids' => 'La bildoj nepre dimensiu malpli ol @maxi@ (tiu dosiero dimensias @actuel@).',
	'info_image_max_taille' => 'La bildoj nepre dimensiu malpli ol @maxi@ (tiu dosiero dimensias @actuel@).',
	'info_inclusion_directe' => 'Rekta inkludo :',
	'info_inclusion_vignette' => 'Inkludo de la vinjeto :',
	'info_installer_tous_documents' => 'Instali ĉiujn dokumentojn',
	'info_largeur' => 'Larĝo',
	'info_logo_max_taille' => 'Vinjetoj devige pezu malpli ol @maxi@ (tiu dosiero pezas @actuel@).',
	'info_mode' => 'Reĝimo',
	'info_modifier_document' => 'Modifi la dokumenton',
	'info_portfolio' => 'Bildaro',
	'info_referencer_doc_distant' => 'Referencigi dokumenton ĉe la reto :',
	'info_resolution_image' => 'Bilder-denseco',
	'info_resolution_mpx' => '@resolution@ Mpx (milionoj da bilderoj)',
	'info_sans_vignette' => 'Senvinjeta',
	'info_statut_document' => 'Tiu dokumento estas :',
	'info_taille' => 'Dosiergrando',
	'info_telecharger' => 'Alŝuti ekde via komputilo :',
	'info_utilisation' => 'Uzo(j)',
	'infos' => 'Teknikaj informoj',
	'item_autoriser_selectionner_date_en_ligne' => 'Ebligi modifi la daton de ĉiu dokumento',
	'item_non_autoriser_selectionner_date_en_ligne' => 'La dato de la dokumentoj estas tiu, kiam oni almetis ilin reteje',

	// L
	'label_activer_document_objets' => 'Aktivigi la alŝuton por la jeno :',
	'label_apercu' => 'Antaŭvido',
	'label_caracteristiques' => 'Karakterizaĵoj',
	'label_credits' => 'Atribuintaro',
	'label_fichier' => 'Dosiero',
	'label_fichier_vignette' => 'Vinjeto',
	'label_paginer_par' => 'Paĝigi laŭ :',
	'label_parents' => 'Tiu dokumento ligiĝas al',
	'label_refdoc_joindre' => 'Dokumento numero',
	'lien_tout_desordonner' => 'Restarigi la ordon',
	'lien_tout_desordonner_verif' => 'La ordo difinita por tiu listo de dokumentoj estos restarigita. Ĉu vi certas pri tio ?',
	'lien_tout_enlever' => 'Ĉion malligi', # MODIF
	'logo' => 'Vinjeto',

	// M
	'media_audio' => 'Sontrakoj',
	'media_file' => 'Aliaj',
	'media_image' => 'Bildoj',
	'media_video' => 'Filmoj',
	'miniature_automatique_active' => 'SPIP kreos aŭtomate vinjeton el la bildo',

	// N
	'nb_documents_attache_succes' => '@nb@ dokumentoj aldonitaj',
	'nb_documents_installe_succes' => '@nb@ sukcese instalitaj dosieroj',

	// O
	'objet_document' => 'Dokumento',
	'objet_documents' => 'Dokumentoj',
	'ordonner_ce_document' => 'Ordigi tiun dokumenton',

	// P
	'par_date' => 'Dato',
	'par_hauteur' => 'Alto',
	'par_id' => 'Identigilo',
	'par_largeur' => 'Larĝo',
	'par_taille' => 'Dosiergrando',
	'par_titre' => 'Titolo',

	// T
	'texte_documents_joints' => 'Vi povas permesi la aldonon de dokumentoj (oficajn dosierojn, bildojn, aŭd-vidaĵojn, ktp.) al la artikoloj, la rubrikoj kaj aliaj. Tiuj dosieroj povas poste esti referencigitaj en la artikolo aŭ sendepende afiŝitaj.',
	'texte_documents_joints_2' => 'Tiu aranĝo ne malhelpas la alŝuton de bildoj rekte en la artikolojn aŭ la inkludon de dokumentoj rekte en la teksto.',
	'titre_documents_joints' => 'Alkroĉitaj dokumentoj',
	'titre_page_documents_edit' => 'Modifi la dokumenton : @titre@',
	'tous_les_medias' => 'Ĉiuj aŭdvideaĵoj',
	'tout_dossier_upload' => 'La tuta dosierujo @upload@',
	'tout_voir' => 'Ĉion vidi',

	// U
	'un_audio' => '1 sontrako',
	'un_document' => '1 dokumento',
	'un_file' => '1 dokumento',
	'un_image' => '1 bildo',
	'un_video' => '1 filmo',
	'une_utilisation' => '1 uzo',
	'upload_fichier_zip' => 'ZIP-Dosiero (densigita)',
	'upload_fichier_zip_texte' => 'La dosiero, kiun vi proponas instali estas densigita dosiero (zip).',
	'upload_fichier_zip_texte2' => 'Tiu dosiero povas esti :',
	'upload_info_mode_document' => 'Meti en la dokumentujo',
	'upload_info_mode_image' => 'Formeti el la dokumentujo',
	'upload_limit' => 'Tiu dosiero estas tro granda por la servilo ; la maksimuma grandeco permesata en <i>upload</i> estas @max@.',
	'upload_zip_conserver' => 'Konservi la arĥivon post maldensigo',
	'upload_zip_decompacter' => 'maldensigita kaj ĉiu elemento, kiun ĝi enhavas estas instalita ĉe la retejo. La dosieroj kiuj estos sekve instalitaj ĉe la retejo estas :',
	'upload_zip_mode_document' => 'Meti ĉiujn bildojn en la dokumetujo',
	'upload_zip_telquel' => 'instalita tia, kia ĝi estas, kiel densigita Zip-arkivo ;',
	'upload_zip_titrer' => 'Titoligi laŭ dosiernomo',

	// V
	'verifier_documents_brises' => 'Kontroli, ĉu mankas dosieroj',
	'verifier_documents_inutilises' => 'Kontroli la ligilojn de la dokumentoj',
	'vignette_supprimee' => 'La vinjeto estis forigita',
];
